@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Params::VERSION   = '1.015_001';
+	$Type::Params::VERSION   = '1.015_002';
 }
 
 $Type::Params::VERSION =~ tr/_//d;
@@ -604,7 +604,7 @@ This is an alternative way of indicating that a parameter is optional.
 The two are not I<exactly> equivalent. The exceptions thrown will
 differ in the type name they mention. (B<Int> versus B<< Optional[Int] >>.)
 
-=item C<< default >> B<< CodeRef|Ref|Str|Undef >>
+=item C<< default >> B<< CodeRef|ScalarRef|Ref|Str|Undef >>
 
 A default may be provided for a parameter.
 
@@ -631,6 +631,15 @@ non-empty hashrefs. For undef, simple strings, numbers, and empty
 structures, avoiding using a coderef will make your parameter processing
 faster.
 
+Instead of a coderef, you can use a reference to a string of Perl source
+code:
+
+ state $check = compile(
+   Int,
+   Int, { default => \ '6 * 111' },
+   Int, { default => \ '9 * 111' },
+ );
+
 The default I<will> be validated against the type constraint, and
 potentially coerced.
 
