@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Parameter::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Parameter::VERSION    = '1.015_001';
+	$Type::Params::Parameter::VERSION    = '1.015_002';
 }
 
 $Type::Params::Parameter::VERSION =~ tr/_//d;
@@ -84,6 +84,9 @@ sub _code_for_default {
 	if ( is_ArrayRef $default ) {
 		return '[]';
 	}
+	if ( is_ScalarRef $default ) {
+		return $$default;
+	}
 
 	$self->_croak( 'Default expected to be undef, string, coderef, or empty arrayref/hashref' );
 }
